@@ -23,9 +23,6 @@ class SetupGenerator:
         return pkg_resources.resource_string(resource_package, resource_path).decode('utf-8')
 
     def read(self):
-        if path.isfile('setup.cfg'):
-            self.config.read('setup.cfg')
-            return
         cfg = self._get_package_resource('setup.cfg')
         self.config.read_string(cfg)
 
@@ -95,11 +92,6 @@ class Setup:
     def __init__(self):
         self.pkg_json = None
         self.generator = SetupGenerator()
-    
-    def setupCfgExists(self):
-        if path.isfile('setup.cfg'):
-            return True
-        return False
 
     def configure(self):
         try:
@@ -111,6 +103,14 @@ class Setup:
         except KeyError as ke:
             raise NoSetupConfiguration(ke)
             sys.exit()
+        
+        try:
+            install_requires = []
+            for dependency, version in self.pkg_json['dependencies'].items():
+                install_requires.append(f'{dependency}=={version}')
+            self.pkg_json['setup']['install_requires'] = install_requires
+        except KeyError as ke:
+            pass
 
     def set_vars(self, pkg_json, update_packages):
         self.pkg_json = pkg_json
@@ -121,10 +121,9 @@ class Setup:
             self.generator.set_generator_var(self.pkg_json['setup'])
             if self.update_packages:
                 self.generator.prereqs()
-            if not self.setupCfgExists():
-                self.generator.read()
-                self.generator.generate()
-                self.generator.write()
+            self.generator.read()
+            self.generator.generate()
+            self.generator.write()
             print('Awaiting setup...')
             time.sleep(3)
             self.generator.run_setup()
